RatioErrorKind

Enum RatioErrorKind 

#[non_exhaustive]
pub enum RatioErrorKind { ParseError, ZeroDenominator, Overflow, }
The specific type of error that occurred during parsing.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ParseError

The string could not be parsed as a ratio.

This occurs if the input string does not match the expected format (e.g., contains invalid characters or is empty).



ZeroDenominator

The denominator was zero.

Ratios cannot have a zero denominator.



Overflow

The parsed value cannot be represented by the target type.

This occurs if the numerator, denominator, or intermediate values overflow the capacity of the integer type T.